@@ -23,7 +23,7 @@ class HomeScreen;
 /**
  * @short Object that represents an application.
  */
-class FolioApplication : public QObject
+class FolioApplication : public QObject, public std::enable_shared_from_this<FolioApplication>
 {
     Q_OBJECT
     Q_PROPERTY(bool running READ running NOTIFY windowChanged)
@@ -32,9 +32,11 @@ class FolioApplication : public QObject
     Q_PROPERTY(QString storageId READ storageId NOTIFY storageIdChanged)
 
 public:
+    typedef std::shared_ptr<FolioApplication> Ptr;
+
     FolioApplication(HomeScreen *parent = nullptr, KService::Ptr service = QExplicitlySharedDataPointer<KService>{nullptr});
 
-    static FolioApplication *fromJson(QJsonObject &obj, HomeScreen *parent); // may return nullptr
+    static FolioApplication::Ptr fromJson(QJsonObject &obj, HomeScreen *parent); // may return nullptr
     QJsonObject toJson() const;
 
     bool running() const;
