@@ -3,6 +3,8 @@
 
 #pragma once
 
+#include "homescreen.h"
+
 #include <QObject>
 
 #include <Plasma/Applet>
@@ -15,8 +17,6 @@ class WidgetsManager : public QObject
 public:
     WidgetsManager(QObject *parent = nullptr);
 
-    static WidgetsManager *self();
-
     Plasma::Applet *getWidget(int id);
 
     void addWidget(Plasma::Applet *applet);
